@@ -1,9 +1,10 @@
 import logging
 import pyo
-from shakersynth.config import config
+from shakersynth.config import loader
 
+config = loader.load_config()
 log = logging.getLogger(__name__)
-log.setLevel(config.log_level)
+log.setLevel(config.log.level)
 
 
 class RotorSynth():
@@ -59,8 +60,16 @@ class RotorSynth():
         `telemetry` must contain the key `rotor_rpm_percent` to have
         any effect.
 
-        Supports the Mi-8 and UH-1H modules.
+        Supports the Mi-8, Mi-24, and UH-1H modules.
         """
+        module = telemetry["module"]
+        if(module == "mi-8mt" or module == "mi-24p"):
+            blade_count = 5
+        elif(module == "uh-1h"):
+            blade_count = 2
+        else:
+            raise NotImplementedError
+
         rpm = self._calculate_rotor_rpm(telemetry)
 
         # Protect against divide-by-zero errors.
@@ -70,14 +79,6 @@ class RotorSynth():
         # Revolutions per second is more useful than RPM.
         revolutions_per_second = rpm / 60.0
 
-        module = telemetry["module"]
-        if(module == "mi-8mt" or module == "mi-24p"):
-            blade_count = 5
-        elif(module == "uh-1h"):
-            blade_count = 2
-        else:
-            raise NotImplementedError
-
         blades_per_second = revolutions_per_second * blade_count
         log.debug(f"blades_per_second: {blades_per_second}")
         self.osc0.setFreq(blades_per_second)
